# -*- coding: utf-8 -*-

from django.db.models import Q

from ..timetable import TimetableFactory, Category
from ..models import EdtClubs


"""
Backend for the user's clubs timetables.
"""


def get_timetables_for(user, result):
    """
    Backend main function
    Returns the clubs timetables for the specified user in the result list.
    """

    if user.edt_club_events is None or user.edt_club_events == 0:
        return

    user_clubs = [club.cn for club in user.get_clubs()]

    start, end = TimetableFactory.get_limits()

    filter = Q(club__in=user_clubs)
    if user.edt_club_events == 2:
        filter |= Q(public=True)
    filter &= Q(start__lte=end, end__gte=start)

    query = EdtClubs.objects.filter(filter)
    if not query:
        return

    factory = TimetableFactory(f"Événements clubs de {user}")
    for event in query:
        factory.add_event(
            event.start,
            event.end,
            event.topic,
            None,
            Category.CLUB,
            [event.location],
            [event.people],
            f"Net7 Club - id {event.id}",
        )

    result.append(factory.table)
